# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.beta.models.user_app_account import UserAppAccount
from sailpoint.beta.models.user_app_owner import UserAppOwner
from sailpoint.beta.models.user_app_source import UserAppSource
from sailpoint.beta.models.user_app_source_app import UserAppSourceApp
from typing import Optional, Set
from typing_extensions import Self

class UserApp(BaseModel):
    """
    UserApp
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="The user app id")
    created: Optional[datetime] = Field(default=None, description="Time when the user app was created")
    modified: Optional[datetime] = Field(default=None, description="Time when the user app was last modified")
    has_multiple_accounts: Optional[StrictBool] = Field(default=False, description="True if the owner has multiple accounts for the source", alias="hasMultipleAccounts")
    use_for_password_management: Optional[StrictBool] = Field(default=False, description="True if the source has password feature", alias="useForPasswordManagement")
    provision_request_enabled: Optional[StrictBool] = Field(default=False, description="True if the source app related to the user app is provision request enabled", alias="provisionRequestEnabled")
    app_center_enabled: Optional[StrictBool] = Field(default=True, description="True if the source app related to the user app is shown in the app center", alias="appCenterEnabled")
    source_app: Optional[UserAppSourceApp] = Field(default=None, alias="sourceApp")
    source: Optional[UserAppSource] = None
    account: Optional[UserAppAccount] = None
    owner: Optional[UserAppOwner] = None
    __properties: ClassVar[List[str]] = ["id", "created", "modified", "hasMultipleAccounts", "useForPasswordManagement", "provisionRequestEnabled", "appCenterEnabled", "sourceApp", "source", "account", "owner"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserApp from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source_app
        if self.source_app:
            _dict['sourceApp'] = self.source_app.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of account
        if self.account:
            _dict['account'] = self.account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserApp from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "hasMultipleAccounts": obj.get("hasMultipleAccounts") if obj.get("hasMultipleAccounts") is not None else False,
            "useForPasswordManagement": obj.get("useForPasswordManagement") if obj.get("useForPasswordManagement") is not None else False,
            "provisionRequestEnabled": obj.get("provisionRequestEnabled") if obj.get("provisionRequestEnabled") is not None else False,
            "appCenterEnabled": obj.get("appCenterEnabled") if obj.get("appCenterEnabled") is not None else True,
            "sourceApp": UserAppSourceApp.from_dict(obj["sourceApp"]) if obj.get("sourceApp") is not None else None,
            "source": UserAppSource.from_dict(obj["source"]) if obj.get("source") is not None else None,
            "account": UserAppAccount.from_dict(obj["account"]) if obj.get("account") is not None else None,
            "owner": UserAppOwner.from_dict(obj["owner"]) if obj.get("owner") is not None else None
        })
        return _obj


