# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.certification_campaigns_api import CertificationCampaignsApi


class TestCertificationCampaignsApi(unittest.TestCase):
    """CertificationCampaignsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CertificationCampaignsApi()

    def tearDown(self) -> None:
        pass

    def test_complete_campaign(self) -> None:
        """Test case for complete_campaign

        Complete a campaign
        """
        pass

    def test_create_campaign(self) -> None:
        """Test case for create_campaign

        Create a campaign
        """
        pass

    def test_create_campaign_template(self) -> None:
        """Test case for create_campaign_template

        Create a campaign template
        """
        pass

    def test_delete_campaign_template(self) -> None:
        """Test case for delete_campaign_template

        Delete a campaign template
        """
        pass

    def test_delete_campaign_template_schedule(self) -> None:
        """Test case for delete_campaign_template_schedule

        Delete campaign template schedule
        """
        pass

    def test_delete_campaigns(self) -> None:
        """Test case for delete_campaigns

        Delete campaigns
        """
        pass

    def test_get_active_campaigns(self) -> None:
        """Test case for get_active_campaigns

        List campaigns
        """
        pass

    def test_get_campaign(self) -> None:
        """Test case for get_campaign

        Get campaign
        """
        pass

    def test_get_campaign_reports(self) -> None:
        """Test case for get_campaign_reports

        Get campaign reports
        """
        pass

    def test_get_campaign_reports_config(self) -> None:
        """Test case for get_campaign_reports_config

        Get campaign reports configuration
        """
        pass

    def test_get_campaign_template(self) -> None:
        """Test case for get_campaign_template

        Get a campaign template
        """
        pass

    def test_get_campaign_template_schedule(self) -> None:
        """Test case for get_campaign_template_schedule

        Get campaign template schedule
        """
        pass

    def test_get_campaign_templates(self) -> None:
        """Test case for get_campaign_templates

        List campaign templates
        """
        pass

    def test_move(self) -> None:
        """Test case for move

        Reassign certifications
        """
        pass

    def test_patch_campaign_template(self) -> None:
        """Test case for patch_campaign_template

        Update a campaign template
        """
        pass

    def test_set_campaign_reports_config(self) -> None:
        """Test case for set_campaign_reports_config

        Set campaign reports configuration
        """
        pass

    def test_set_campaign_template_schedule(self) -> None:
        """Test case for set_campaign_template_schedule

        Set campaign template schedule
        """
        pass

    def test_start_campaign(self) -> None:
        """Test case for start_campaign

        Activate a campaign
        """
        pass

    def test_start_campaign_remediation_scan(self) -> None:
        """Test case for start_campaign_remediation_scan

        Run campaign remediation scan
        """
        pass

    def test_start_campaign_report(self) -> None:
        """Test case for start_campaign_report

        Run campaign report
        """
        pass

    def test_start_generate_campaign_template(self) -> None:
        """Test case for start_generate_campaign_template

        Generate a campaign from template
        """
        pass

    def test_update_campaign(self) -> None:
        """Test case for update_campaign

        Update a campaign
        """
        pass


if __name__ == '__main__':
    unittest.main()
