# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.models.connector_detail import ConnectorDetail

class TestConnectorDetail(unittest.TestCase):
    """ConnectorDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConnectorDetail:
        """Test ConnectorDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConnectorDetail`
        """
        model = ConnectorDetail()
        if include_optional:
            return ConnectorDetail(
                name = 'name',
                type = 'ServiceNow',
                class_name = 'class name',
                script_name = 'servicenow',
                application_xml = '<?xml version='1.0' encoding='UTF-8'?>
<!DOCTYPE Application PUBLIC "sailpoint.dtd" "sailpoint.dtd">
<Application connector="sailpoint.connector.OpenConnectorAdapter" name="custom Atlassian Suite - Cloud" type="custom Atlassian Suite - Cloud"/>
',
                correlation_config_xml = '<?xml version='1.0' encoding='UTF-8'?>
<!-- Copyright (C) 2021 SailPoint Technologies, Inc.  All rights reserved. -->

<!DOCTYPE CorrelationConfig PUBLIC "sailpoint.dtd" "sailpoint.dtd">

<CorrelationConfig name="custom Atlassian Suite - Cloud Account Correlation Config">
	<AttributeAssignments>
		<Filter operation="EQ" property="email" value="mail"/>
		<Filter operation="EQ" property="empId" value="employeeNumber"/>
		<Filter operation="EQ" property="displayName" value="cn"/>
	</AttributeAssignments>
</CorrelationConfig>
',
                source_config_xml = '<?xml version="1.0" encoding="UTF-8" standalone="no"?><!-- Copyright (C) 2023 SailPoint Technologies, Inc.  All rights reserved. --><Form xmlns="http://www.sailpoint.com/xsd/sailpoint_form_2_0.xsd" connectorName="custom Atlassian Suite - Cloud" directConnect="true" fileUpload="true" name="Custom Atlassian Suite - Cloud" status="released" type="SourceConfig">
    <BaseConfig>
        <Field maxFiles="10" maxSize="300" name="fileUpload" supportedExtensions="jar" type="fileupload" validateJSON="false"/>
    </BaseConfig>
  

 
</Form>',
                source_config = '<?xml version="1.0" encoding="UTF-8" standalone="no"?><!-- Copyright (C) 2023 SailPoint Technologies, Inc.  All rights reserved. --><Form xmlns="http://www.sailpoint.com/xsd/sailpoint_form_2_0.xsd" connectorName="custom Atlassian Suite - Cloud" directConnect="true" fileUpload="true" name="Custom Atlassian Suite - Cloud" status="released" type="SourceConfig">
    <BaseConfig>
        <Field maxFiles="10" maxSize="300" name="fileUpload" supportedExtensions="jar" type="fileupload" validateJSON="false"/>
    </BaseConfig>
  

 
</Form>',
                source_config_from = 'sp-connect',
                s3_location = 'custom-connector/scriptname',
                uploaded_files = [pod/org/connectorFiles/testconnector/test1.jar],
                file_upload = True,
                direct_connect = True,
                translation_properties = {de=# Copyright (C) 2024 SailPoint Technologies, Inc.  All rights reserved.
# DO NOT EDIT. This file is generated by "sailpointTranslate" command.
menuLabel_ConnectionSettings=Verbindungseinstellungen
menuLabel_AggregationSettings=Aggregationseinstellungen
sectionLabel_AuthenticationSettings=Verbindungseinstellungen
sectionLabel_AggregationSettings=Aggregationseinstellungen
sectionInfo_AuthenticationSettings=Konfigurieren Sie eine direkte Verbindung zwischen der Quelle Delinea Secret Server On-Premise und IdentityNow.<br><br>Geben Sie bei <strong>Zeit\u00fcberschreitung bei Verbindung</strong> die maximal erlaubte Zeitdauer (in Minuten) f\u00fcr die Verbindung von IdentityNow mit der Quelle ein.<br><br>Geben Sie die <strong>Host-URL</strong> der Delinea-SCIM-Serverquelle ein.<br><br>Geben Sie den <strong>API-Token</strong> der Quelle zur Authentifizierung ein.
sectionInfo_AggregationSettings=Geben Sie die Einstellungen f\u00fcr Ihre Aggregation an.<br><br>Geben Sie in das Feld  <strong>Seitengr\u00f6\u00dfe</strong> die Anzahl an Kontoeintr\u00e4gen ein, die auf einer einzelnen Seite aggregiert werden sollen, wenn gro\u00dfe Datens\u00e4tze durchlaufen werden.<br>\n<br>Geben Sie im <strong>Kontofilter</strong> die Bedingungen f\u00fcr den Kontofilter an. Beispiel: userName sw "S"<br><br>Geben Sie im <strong>Gruppenfilter</strong> die Gruppenfilterbedingungen an. Beispiel: displayName sw "S".
placeHolder_accAggregation=userName sw "S"
placeHolder_grpAggregation=displayName sw "S"
placeHolder_host=https://{Delinea_SCIM_Server_host}/v2
docLinkLabel_AuthenticationSettings=Mehr \u00fcber Verbindungseinstellungen
docLinkLabel_Filters=Mehr \u00fcber Konto- und Gruppenfilter
HostURL=Host-URL
ConnectionTimeout=Zeit\u00fcberschreitung bei Verbindung
API_TOKEN=API-Token
JSONPathMapping=JSON-Path-Attribut-Mapping
FilterConditionForAccounts=Kontofilter
FilterConditionForGroups=Gruppenfilter
Page_Size=Seitengr\u00f6\u00dfe
SchemaAttribute=Schema-Attribut
JSONpath=JSON-Pfad
ShortDesc=Das Integrationsmodul IdentityNow f\u00fcr Delinea Secret Server On-Premise bietet die M\u00f6glichkeit einer tiefen Governance f\u00fcr Konten und Gruppen. Es unterst\u00fctzt au\u00dferdem das End-to-End-Lebenszyklus-Management.},
                connector_metadata = {supportedUI=EXTJS, platform=ccg, shortDesc=connector description},
                status = 'RELEASED'
            )
        else:
            return ConnectorDetail(
        )
        """

    def testConnectorDetail(self):
        """Test ConnectorDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
