# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.dimensions_api import DimensionsApi


class TestDimensionsApi(unittest.TestCase):
    """DimensionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DimensionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_dimension(self) -> None:
        """Test case for create_dimension

        Create a dimension
        """
        pass

    def test_delete_bulk_dimensions(self) -> None:
        """Test case for delete_bulk_dimensions

        Delete dimension(s)
        """
        pass

    def test_delete_dimension(self) -> None:
        """Test case for delete_dimension

        Delete a dimension
        """
        pass

    def test_get_dimension(self) -> None:
        """Test case for get_dimension

        Get a dimension under role.
        """
        pass

    def test_get_dimension_entitlements(self) -> None:
        """Test case for get_dimension_entitlements

        List dimension's entitlements
        """
        pass

    def test_list_dimension_access_profiles(self) -> None:
        """Test case for list_dimension_access_profiles

        List dimension's access profiles
        """
        pass

    def test_list_dimensions(self) -> None:
        """Test case for list_dimensions

        List dimensions
        """
        pass

    def test_patch_dimension(self) -> None:
        """Test case for patch_dimension

        Patch a specified dimension
        """
        pass


if __name__ == '__main__':
    unittest.main()
