# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.accounts_api import AccountsApi


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountsApi()

    def tearDown(self) -> None:
        pass

    def test_create_account(self) -> None:
        """Test case for create_account

        Create account
        """
        pass

    def test_delete_account(self) -> None:
        """Test case for delete_account

        Delete account
        """
        pass

    def test_delete_account_async(self) -> None:
        """Test case for delete_account_async

        Remove account
        """
        pass

    def test_disable_account(self) -> None:
        """Test case for disable_account

        Disable account
        """
        pass

    def test_disable_account_for_identity(self) -> None:
        """Test case for disable_account_for_identity

        Disable idn account for identity
        """
        pass

    def test_disable_accounts_for_identities(self) -> None:
        """Test case for disable_accounts_for_identities

        Disable idn accounts for identities
        """
        pass

    def test_enable_account(self) -> None:
        """Test case for enable_account

        Enable account
        """
        pass

    def test_enable_account_for_identity(self) -> None:
        """Test case for enable_account_for_identity

        Enable idn account for identity
        """
        pass

    def test_enable_accounts_for_identities(self) -> None:
        """Test case for enable_accounts_for_identities

        Enable idn accounts for identities
        """
        pass

    def test_get_account(self) -> None:
        """Test case for get_account

        Account details
        """
        pass

    def test_get_account_entitlements(self) -> None:
        """Test case for get_account_entitlements

        Account entitlements
        """
        pass

    def test_list_accounts(self) -> None:
        """Test case for list_accounts

        Accounts list
        """
        pass

    def test_put_account(self) -> None:
        """Test case for put_account

        Update account
        """
        pass

    def test_submit_reload_account(self) -> None:
        """Test case for submit_reload_account

        Reload account
        """
        pass

    def test_unlock_account(self) -> None:
        """Test case for unlock_account

        Unlock account
        """
        pass

    def test_update_account(self) -> None:
        """Test case for update_account

        Update account
        """
        pass


if __name__ == '__main__':
    unittest.main()
