# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.data_segmentation_api import DataSegmentationApi


class TestDataSegmentationApi(unittest.TestCase):
    """DataSegmentationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataSegmentationApi()

    def tearDown(self) -> None:
        pass

    def test_create_data_segment(self) -> None:
        """Test case for create_data_segment

        Create segment
        """
        pass

    def test_delete_data_segment(self) -> None:
        """Test case for delete_data_segment

        Delete segment by id
        """
        pass

    def test_get_data_segment(self) -> None:
        """Test case for get_data_segment

        Get segment by id
        """
        pass

    def test_get_data_segment_identity_membership(self) -> None:
        """Test case for get_data_segment_identity_membership

        Get segmentmembership by identity id
        """
        pass

    def test_get_data_segmentation_enabled_for_user(self) -> None:
        """Test case for get_data_segmentation_enabled_for_user

        Is segmentation enabled by identity
        """
        pass

    def test_list_data_segments(self) -> None:
        """Test case for list_data_segments

        Get segments
        """
        pass

    def test_patch_data_segment(self) -> None:
        """Test case for patch_data_segment

        Update segment
        """
        pass

    def test_publish_data_segment(self) -> None:
        """Test case for publish_data_segment

        Publish segment by id
        """
        pass


if __name__ == '__main__':
    unittest.main()
