# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.configuration_hub_api import ConfigurationHubApi


class TestConfigurationHubApi(unittest.TestCase):
    """ConfigurationHubApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfigurationHubApi()

    def tearDown(self) -> None:
        pass

    def test_create_deploy(self) -> None:
        """Test case for create_deploy

        Create a deploy
        """
        pass

    def test_create_object_mapping(self) -> None:
        """Test case for create_object_mapping

        Creates an object mapping
        """
        pass

    def test_create_object_mappings(self) -> None:
        """Test case for create_object_mappings

        Bulk creates object mappings
        """
        pass

    def test_create_scheduled_action(self) -> None:
        """Test case for create_scheduled_action

        Create scheduled action
        """
        pass

    def test_create_uploaded_configuration(self) -> None:
        """Test case for create_uploaded_configuration

        Upload a configuration
        """
        pass

    def test_delete_backup(self) -> None:
        """Test case for delete_backup

        Delete a backup
        """
        pass

    def test_delete_draft(self) -> None:
        """Test case for delete_draft

        Delete a draft
        """
        pass

    def test_delete_object_mapping(self) -> None:
        """Test case for delete_object_mapping

        Deletes an object mapping
        """
        pass

    def test_delete_scheduled_action(self) -> None:
        """Test case for delete_scheduled_action

        Delete scheduled action
        """
        pass

    def test_delete_uploaded_configuration(self) -> None:
        """Test case for delete_uploaded_configuration

        Delete an uploaded configuration
        """
        pass

    def test_get_deploy(self) -> None:
        """Test case for get_deploy

        Get a deploy
        """
        pass

    def test_get_object_mappings(self) -> None:
        """Test case for get_object_mappings

        Gets list of object mappings
        """
        pass

    def test_get_uploaded_configuration(self) -> None:
        """Test case for get_uploaded_configuration

        Get an uploaded configuration
        """
        pass

    def test_list_backups(self) -> None:
        """Test case for list_backups

        List backups
        """
        pass

    def test_list_deploys(self) -> None:
        """Test case for list_deploys

        List deploys
        """
        pass

    def test_list_drafts(self) -> None:
        """Test case for list_drafts

        List drafts
        """
        pass

    def test_list_scheduled_actions(self) -> None:
        """Test case for list_scheduled_actions

        List scheduled actions
        """
        pass

    def test_list_uploaded_configurations(self) -> None:
        """Test case for list_uploaded_configurations

        List uploaded configurations
        """
        pass

    def test_update_object_mappings(self) -> None:
        """Test case for update_object_mappings

        Bulk updates object mappings
        """
        pass

    def test_update_scheduled_action(self) -> None:
        """Test case for update_scheduled_action

        Update scheduled action
        """
        pass


if __name__ == '__main__':
    unittest.main()
