# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.identity_attributes_api import IdentityAttributesApi


class TestIdentityAttributesApi(unittest.TestCase):
    """IdentityAttributesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityAttributesApi()

    def tearDown(self) -> None:
        pass

    def test_create_identity_attribute(self) -> None:
        """Test case for create_identity_attribute

        Create identity attribute
        """
        pass

    def test_delete_identity_attribute(self) -> None:
        """Test case for delete_identity_attribute

        Delete identity attribute
        """
        pass

    def test_delete_identity_attributes_in_bulk(self) -> None:
        """Test case for delete_identity_attributes_in_bulk

        Bulk delete identity attributes
        """
        pass

    def test_get_identity_attribute(self) -> None:
        """Test case for get_identity_attribute

        Get identity attribute
        """
        pass

    def test_list_identity_attributes(self) -> None:
        """Test case for list_identity_attributes

        List identity attributes
        """
        pass

    def test_put_identity_attribute(self) -> None:
        """Test case for put_identity_attribute

        Update identity attribute
        """
        pass


if __name__ == '__main__':
    unittest.main()
