# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.tenant_context_api import TenantContextApi


class TestTenantContextApi(unittest.TestCase):
    """TenantContextApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TenantContextApi()

    def tearDown(self) -> None:
        pass

    def test_get_tenant_context(self) -> None:
        """Test case for get_tenant_context

        Retrieve tenant context
        """
        pass

    def test_patch_tenant_context(self) -> None:
        """Test case for patch_tenant_context

        Update tenant context
        """
        pass


if __name__ == '__main__':
    unittest.main()
