# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sailpoint.v2025.models.access_item_associated_access_item import AccessItemAssociatedAccessItem
from sailpoint.v2025.models.correlated_governance_event import CorrelatedGovernanceEvent
from typing import Optional, Set
from typing_extensions import Self

class AccessItemRemoved(BaseModel):
    """
    AccessItemRemoved
    """ # noqa: E501
    access_item: AccessItemAssociatedAccessItem = Field(alias="accessItem")
    identity_id: Optional[StrictStr] = Field(default=None, description="the identity id", alias="identityId")
    event_type: Optional[StrictStr] = Field(default=None, description="the event type", alias="eventType")
    date_time: Optional[StrictStr] = Field(default=None, description="the date of event", alias="dateTime")
    access_item_type: Optional[StrictStr] = Field(default=None, description="the access item type", alias="accessItemType")
    governance_event: Optional[CorrelatedGovernanceEvent] = Field(default=None, alias="governanceEvent")
    __properties: ClassVar[List[str]] = ["accessItem", "identityId", "eventType", "dateTime", "accessItemType", "governanceEvent"]

    @field_validator('access_item_type')
    def access_item_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['account', 'app', 'entitlement', 'role', 'accessProfile']):
            warnings.warn(f"must be one of enum values ('account', 'app', 'entitlement', 'role', 'accessProfile') unknown value: {value}")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccessItemRemoved from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of access_item
        if self.access_item:
            _dict['accessItem'] = self.access_item.to_dict()
        # override the default output from pydantic by calling `to_dict()` of governance_event
        if self.governance_event:
            _dict['governanceEvent'] = self.governance_event.to_dict()
        # set to None if governance_event (nullable) is None
        # and model_fields_set contains the field
        if self.governance_event is None and "governance_event" in self.model_fields_set:
            _dict['governanceEvent'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccessItemRemoved from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accessItem": AccessItemAssociatedAccessItem.from_dict(obj["accessItem"]) if obj.get("accessItem") is not None else None,
            "identityId": obj.get("identityId"),
            "eventType": obj.get("eventType"),
            "dateTime": obj.get("dateTime"),
            "accessItemType": obj.get("accessItemType"),
            "governanceEvent": CorrelatedGovernanceEvent.from_dict(obj["governanceEvent"]) if obj.get("governanceEvent") is not None else None
        })
        return _obj


