# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.identity_history_api import IdentityHistoryApi


class TestIdentityHistoryApi(unittest.TestCase):
    """IdentityHistoryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityHistoryApi()

    def tearDown(self) -> None:
        pass

    def test_compare_identity_snapshots(self) -> None:
        """Test case for compare_identity_snapshots

        Gets a difference of count for each access item types for the given identity between 2 snapshots
        """
        pass

    def test_compare_identity_snapshots_access_type(self) -> None:
        """Test case for compare_identity_snapshots_access_type

        Gets a list of differences of specific accesstype for the given identity between 2 snapshots
        """
        pass

    def test_get_historical_identity(self) -> None:
        """Test case for get_historical_identity

        Get latest snapshot of identity
        """
        pass

    def test_get_historical_identity_events(self) -> None:
        """Test case for get_historical_identity_events

        List identity event history
        """
        pass

    def test_get_identity_snapshot(self) -> None:
        """Test case for get_identity_snapshot

        Gets an identity snapshot at a given date
        """
        pass

    def test_get_identity_snapshot_summary(self) -> None:
        """Test case for get_identity_snapshot_summary

        Gets the summary for the event count for a specific identity
        """
        pass

    def test_get_identity_start_date(self) -> None:
        """Test case for get_identity_start_date

        Gets the start date of the identity
        """
        pass

    def test_list_historical_identities(self) -> None:
        """Test case for list_historical_identities

        Lists all the identities
        """
        pass

    def test_list_identity_access_items(self) -> None:
        """Test case for list_identity_access_items

        List access items by identity
        """
        pass

    def test_list_identity_snapshot_access_items(self) -> None:
        """Test case for list_identity_snapshot_access_items

        Get identity access items snapshot
        """
        pass

    def test_list_identity_snapshots(self) -> None:
        """Test case for list_identity_snapshots

        Lists all the snapshots for the identity
        """
        pass


if __name__ == '__main__':
    unittest.main()
