# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.custom_password_instructions_api import CustomPasswordInstructionsApi


class TestCustomPasswordInstructionsApi(unittest.TestCase):
    """CustomPasswordInstructionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomPasswordInstructionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_custom_password_instructions(self) -> None:
        """Test case for create_custom_password_instructions

        Create custom password instructions
        """
        pass

    def test_delete_custom_password_instructions(self) -> None:
        """Test case for delete_custom_password_instructions

        Delete custom password instructions by page id
        """
        pass

    def test_get_custom_password_instructions(self) -> None:
        """Test case for get_custom_password_instructions

        Get custom password instructions by page id
        """
        pass


if __name__ == '__main__':
    unittest.main()
