# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.machine_classification_config_api import MachineClassificationConfigApi


class TestMachineClassificationConfigApi(unittest.TestCase):
    """MachineClassificationConfigApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MachineClassificationConfigApi()

    def tearDown(self) -> None:
        pass

    def test_delete_machine_classification_config(self) -> None:
        """Test case for delete_machine_classification_config

        Delete source's classification config
        """
        pass

    def test_get_machine_classification_config(self) -> None:
        """Test case for get_machine_classification_config

        Machine classification config for source
        """
        pass

    def test_set_machine_classification_config(self) -> None:
        """Test case for set_machine_classification_config

        Update source's classification config
        """
        pass


if __name__ == '__main__':
    unittest.main()
