# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.saved_search_api import SavedSearchApi


class TestSavedSearchApi(unittest.TestCase):
    """SavedSearchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SavedSearchApi()

    def tearDown(self) -> None:
        pass

    def test_create_saved_search(self) -> None:
        """Test case for create_saved_search

        Create a saved search
        """
        pass

    def test_delete_saved_search(self) -> None:
        """Test case for delete_saved_search

        Delete document by id
        """
        pass

    def test_execute_saved_search(self) -> None:
        """Test case for execute_saved_search

        Execute a saved search by id
        """
        pass

    def test_get_saved_search(self) -> None:
        """Test case for get_saved_search

        Return saved search by id
        """
        pass

    def test_list_saved_searches(self) -> None:
        """Test case for list_saved_searches

        A list of saved searches
        """
        pass

    def test_put_saved_search(self) -> None:
        """Test case for put_saved_search

        Updates an existing saved search 
        """
        pass


if __name__ == '__main__':
    unittest.main()
