# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.password_policies_api import PasswordPoliciesApi


class TestPasswordPoliciesApi(unittest.TestCase):
    """PasswordPoliciesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordPoliciesApi()

    def tearDown(self) -> None:
        pass

    def test_create_password_policy(self) -> None:
        """Test case for create_password_policy

        Create password policy
        """
        pass

    def test_delete_password_policy(self) -> None:
        """Test case for delete_password_policy

        Delete password policy by id
        """
        pass

    def test_get_password_policy_by_id(self) -> None:
        """Test case for get_password_policy_by_id

        Get password policy by id
        """
        pass

    def test_list_password_policies(self) -> None:
        """Test case for list_password_policies

        List password policies
        """
        pass

    def test_set_password_policy(self) -> None:
        """Test case for set_password_policy

        Update password policy by id
        """
        pass


if __name__ == '__main__':
    unittest.main()
