# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.identities_api import IdentitiesApi


class TestIdentitiesApi(unittest.TestCase):
    """IdentitiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentitiesApi()

    def tearDown(self) -> None:
        pass

    def test_delete_identity(self) -> None:
        """Test case for delete_identity

        Delete identity
        """
        pass

    def test_get_identity(self) -> None:
        """Test case for get_identity

        Identity details
        """
        pass

    def test_get_identity_ownership_details(self) -> None:
        """Test case for get_identity_ownership_details

        Get ownership details
        """
        pass

    def test_get_role_assignment(self) -> None:
        """Test case for get_role_assignment

        Role assignment details
        """
        pass

    def test_get_role_assignments(self) -> None:
        """Test case for get_role_assignments

        List role assignments
        """
        pass

    def test_list_identities(self) -> None:
        """Test case for list_identities

        List identities
        """
        pass

    def test_reset_identity(self) -> None:
        """Test case for reset_identity

        Reset an identity
        """
        pass

    def test_send_identity_verification_account_token(self) -> None:
        """Test case for send_identity_verification_account_token

        Send password reset email
        """
        pass

    def test_start_identities_invite(self) -> None:
        """Test case for start_identities_invite

        Invite identities to register
        """
        pass

    def test_start_identity_processing(self) -> None:
        """Test case for start_identity_processing

        Process a list of identityids
        """
        pass

    def test_synchronize_attributes_for_identity(self) -> None:
        """Test case for synchronize_attributes_for_identity

        Attribute synchronization for single identity.
        """
        pass


if __name__ == '__main__':
    unittest.main()
