# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.multi_host_integration_api import MultiHostIntegrationApi


class TestMultiHostIntegrationApi(unittest.TestCase):
    """MultiHostIntegrationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MultiHostIntegrationApi()

    def tearDown(self) -> None:
        pass

    def test_create_multi_host_integration(self) -> None:
        """Test case for create_multi_host_integration

        Create multi-host integration
        """
        pass

    def test_create_sources_within_multi_host(self) -> None:
        """Test case for create_sources_within_multi_host

        Create sources within multi-host integration
        """
        pass

    def test_delete_multi_host(self) -> None:
        """Test case for delete_multi_host

        Delete multi-host integration
        """
        pass

    def test_get_acct_aggregation_groups(self) -> None:
        """Test case for get_acct_aggregation_groups

        List account-aggregation-groups by multi-host id
        """
        pass

    def test_get_entitlement_aggregation_groups(self) -> None:
        """Test case for get_entitlement_aggregation_groups

        List entitlement-aggregation-groups by integration id
        """
        pass

    def test_get_multi_host_integrations(self) -> None:
        """Test case for get_multi_host_integrations

        Get multi-host integration by id
        """
        pass

    def test_get_multi_host_integrations_list(self) -> None:
        """Test case for get_multi_host_integrations_list

        List all existing multi-host integrations
        """
        pass

    def test_get_multi_host_source_creation_errors(self) -> None:
        """Test case for get_multi_host_source_creation_errors

        List multi-host source creation errors
        """
        pass

    def test_get_multihost_integration_types(self) -> None:
        """Test case for get_multihost_integration_types

        List multi-host integration types
        """
        pass

    def test_get_sources_within_multi_host(self) -> None:
        """Test case for get_sources_within_multi_host

        List sources within multi-host integration
        """
        pass

    def test_test_connection_multi_host_sources(self) -> None:
        """Test case for test_connection_multi_host_sources

        Test configuration for multi-host integration
        """
        pass

    def test_test_source_connection_multihost(self) -> None:
        """Test case for test_source_connection_multihost

        Test configuration for multi-host integration's single source
        """
        pass

    def test_update_multi_host_sources(self) -> None:
        """Test case for update_multi_host_sources

        Update multi-host integration
        """
        pass


if __name__ == '__main__':
    unittest.main()
