# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.apps_api import AppsApi


class TestAppsApi(unittest.TestCase):
    """AppsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AppsApi()

    def tearDown(self) -> None:
        pass

    def test_create_source_app(self) -> None:
        """Test case for create_source_app

        Create source app
        """
        pass

    def test_delete_access_profiles_from_source_app_by_bulk(self) -> None:
        """Test case for delete_access_profiles_from_source_app_by_bulk

        Bulk remove access profiles from the specified source app
        """
        pass

    def test_delete_source_app(self) -> None:
        """Test case for delete_source_app

        Delete source app by id
        """
        pass

    def test_get_source_app(self) -> None:
        """Test case for get_source_app

        Get source app by id
        """
        pass

    def test_list_access_profiles_for_source_app(self) -> None:
        """Test case for list_access_profiles_for_source_app

        List access profiles for the specified source app
        """
        pass

    def test_list_all_source_app(self) -> None:
        """Test case for list_all_source_app

        List all source apps
        """
        pass

    def test_list_all_user_apps(self) -> None:
        """Test case for list_all_user_apps

        List all user apps
        """
        pass

    def test_list_assigned_source_app(self) -> None:
        """Test case for list_assigned_source_app

        List assigned source apps
        """
        pass

    def test_list_available_accounts_for_user_app(self) -> None:
        """Test case for list_available_accounts_for_user_app

        List available accounts for user app
        """
        pass

    def test_list_available_source_apps(self) -> None:
        """Test case for list_available_source_apps

        List available source apps
        """
        pass

    def test_list_owned_user_apps(self) -> None:
        """Test case for list_owned_user_apps

        List owned user apps
        """
        pass

    def test_patch_source_app(self) -> None:
        """Test case for patch_source_app

        Patch source app by id
        """
        pass

    def test_patch_user_app(self) -> None:
        """Test case for patch_user_app

        Patch user app by id
        """
        pass

    def test_update_source_apps_in_bulk(self) -> None:
        """Test case for update_source_apps_in_bulk

        Bulk update source apps
        """
        pass


if __name__ == '__main__':
    unittest.main()
