# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.models.non_employee_identity_dto_type import NonEmployeeIdentityDtoType

class TestNonEmployeeIdentityDtoType(unittest.TestCase):
    """NonEmployeeIdentityDtoType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNonEmployeeIdentityDtoType(self):
        """Test NonEmployeeIdentityDtoType"""
        # inst = NonEmployeeIdentityDtoType()

if __name__ == '__main__':
    unittest.main()
