# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.application_discovery_api import ApplicationDiscoveryApi


class TestApplicationDiscoveryApi(unittest.TestCase):
    """ApplicationDiscoveryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationDiscoveryApi()

    def tearDown(self) -> None:
        pass

    def test_get_discovered_applications(self) -> None:
        """Test case for get_discovered_applications

        Get discovered applications for tenant
        """
        pass

    def test_get_manual_discover_applications_csv_template(self) -> None:
        """Test case for get_manual_discover_applications_csv_template

        Download csv template for discovery
        """
        pass

    def test_send_manual_discover_applications_csv_template(self) -> None:
        """Test case for send_manual_discover_applications_csv_template

        Upload csv to discover applications
        """
        pass


if __name__ == '__main__':
    unittest.main()
