# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.task_management_api import TaskManagementApi


class TestTaskManagementApi(unittest.TestCase):
    """TaskManagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TaskManagementApi()

    def tearDown(self) -> None:
        pass

    def test_get_pending_task_headers(self) -> None:
        """Test case for get_pending_task_headers

        Retrieve pending task list headers
        """
        pass

    def test_get_pending_tasks(self) -> None:
        """Test case for get_pending_tasks

        Retrieve pending task status list
        """
        pass

    def test_get_task_status(self) -> None:
        """Test case for get_task_status

        Get task status by id
        """
        pass

    def test_get_task_status_list(self) -> None:
        """Test case for get_task_status_list

        Retrieve task status list
        """
        pass

    def test_update_task_status(self) -> None:
        """Test case for update_task_status

        Update task status by id
        """
        pass


if __name__ == '__main__':
    unittest.main()
