# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.machine_account_mappings_api import MachineAccountMappingsApi


class TestMachineAccountMappingsApi(unittest.TestCase):
    """MachineAccountMappingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MachineAccountMappingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_machine_account_mappings(self) -> None:
        """Test case for create_machine_account_mappings

        Create machine account mappings
        """
        pass

    def test_delete_machine_account_mappings(self) -> None:
        """Test case for delete_machine_account_mappings

        Delete source's machine account mappings
        """
        pass

    def test_list_machine_account_mappings(self) -> None:
        """Test case for list_machine_account_mappings

        Machine account mapping for source
        """
        pass

    def test_set_machine_account_mappings(self) -> None:
        """Test case for set_machine_account_mappings

        Update Source's Machine Account Mappings
        """
        pass


if __name__ == '__main__':
    unittest.main()
