# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.reports_data_extraction_api import ReportsDataExtractionApi


class TestReportsDataExtractionApi(unittest.TestCase):
    """ReportsDataExtractionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportsDataExtractionApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_report(self) -> None:
        """Test case for cancel_report

        Cancel report
        """
        pass

    def test_get_report(self) -> None:
        """Test case for get_report

        Get report file
        """
        pass

    def test_get_report_result(self) -> None:
        """Test case for get_report_result

        Get report result
        """
        pass

    def test_start_report(self) -> None:
        """Test case for start_report

        Run report
        """
        pass


if __name__ == '__main__':
    unittest.main()
