# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.managed_clusters_api import ManagedClustersApi


class TestManagedClustersApi(unittest.TestCase):
    """ManagedClustersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedClustersApi()

    def tearDown(self) -> None:
        pass

    def test_create_managed_cluster(self) -> None:
        """Test case for create_managed_cluster

        Create create managed cluster
        """
        pass

    def test_delete_managed_cluster(self) -> None:
        """Test case for delete_managed_cluster

        Delete managed cluster
        """
        pass

    def test_get_client_log_configuration(self) -> None:
        """Test case for get_client_log_configuration

        Get managed cluster log configuration
        """
        pass

    def test_get_managed_cluster(self) -> None:
        """Test case for get_managed_cluster

        Get managed cluster
        """
        pass

    def test_get_managed_clusters(self) -> None:
        """Test case for get_managed_clusters

        Get managed clusters
        """
        pass

    def test_put_client_log_configuration(self) -> None:
        """Test case for put_client_log_configuration

        Update managed cluster log configuration
        """
        pass

    def test_update_managed_cluster(self) -> None:
        """Test case for update_managed_cluster

        Update managed cluster
        """
        pass


if __name__ == '__main__':
    unittest.main()
