# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.custom_user_levels_api import CustomUserLevelsApi


class TestCustomUserLevelsApi(unittest.TestCase):
    """CustomUserLevelsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomUserLevelsApi()

    def tearDown(self) -> None:
        pass

    def test_create_custom_user_level(self) -> None:
        """Test case for create_custom_user_level

        Create a custom user level
        """
        pass

    def test_delete_user_level(self) -> None:
        """Test case for delete_user_level

        Delete a user level
        """
        pass

    def test_get_user_level(self) -> None:
        """Test case for get_user_level

        Retrieve a user level
        """
        pass

    def test_list_all_authorization_right_sets(self) -> None:
        """Test case for list_all_authorization_right_sets

        List all uiAssignable right sets
        """
        pass

    def test_list_user_levels(self) -> None:
        """Test case for list_user_levels

        List user levels
        """
        pass

    def test_publish_custom_user_level(self) -> None:
        """Test case for publish_custom_user_level

        Publish a custom user level
        """
        pass

    def test_update_user_level(self) -> None:
        """Test case for update_user_level

        Update a user level
        """
        pass


if __name__ == '__main__':
    unittest.main()
