# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.public_identities_config_api import PublicIdentitiesConfigApi


class TestPublicIdentitiesConfigApi(unittest.TestCase):
    """PublicIdentitiesConfigApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PublicIdentitiesConfigApi()

    def tearDown(self) -> None:
        pass

    def test_get_public_identity_config(self) -> None:
        """Test case for get_public_identity_config

        Get the public identities configuration
        """
        pass

    def test_update_public_identity_config(self) -> None:
        """Test case for update_public_identity_config

        Update the public identities configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
