# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.managed_cluster_types_api import ManagedClusterTypesApi


class TestManagedClusterTypesApi(unittest.TestCase):
    """ManagedClusterTypesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedClusterTypesApi()

    def tearDown(self) -> None:
        pass

    def test_create_managed_cluster_type(self) -> None:
        """Test case for create_managed_cluster_type

        Create new managed cluster type
        """
        pass

    def test_delete_managed_cluster_type(self) -> None:
        """Test case for delete_managed_cluster_type

        Delete a managed cluster type
        """
        pass

    def test_get_managed_cluster_type(self) -> None:
        """Test case for get_managed_cluster_type

        Get a managed cluster type
        """
        pass

    def test_get_managed_cluster_types(self) -> None:
        """Test case for get_managed_cluster_types

        List managed cluster types
        """
        pass

    def test_update_managed_cluster_type(self) -> None:
        """Test case for update_managed_cluster_type

        Update a managed cluster type
        """
        pass


if __name__ == '__main__':
    unittest.main()
