# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.scheduled_search_api import ScheduledSearchApi


class TestScheduledSearchApi(unittest.TestCase):
    """ScheduledSearchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ScheduledSearchApi()

    def tearDown(self) -> None:
        pass

    def test_create_scheduled_search(self) -> None:
        """Test case for create_scheduled_search

        Create a new scheduled search
        """
        pass

    def test_delete_scheduled_search(self) -> None:
        """Test case for delete_scheduled_search

        Delete a scheduled search
        """
        pass

    def test_get_scheduled_search(self) -> None:
        """Test case for get_scheduled_search

        Get a scheduled search
        """
        pass

    def test_list_scheduled_search(self) -> None:
        """Test case for list_scheduled_search

        List scheduled searches
        """
        pass

    def test_unsubscribe_scheduled_search(self) -> None:
        """Test case for unsubscribe_scheduled_search

        Unsubscribe a recipient from scheduled search
        """
        pass

    def test_update_scheduled_search(self) -> None:
        """Test case for update_scheduled_search

        Update an existing scheduled search
        """
        pass


if __name__ == '__main__':
    unittest.main()
