# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.password_management_api import PasswordManagementApi


class TestPasswordManagementApi(unittest.TestCase):
    """PasswordManagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordManagementApi()

    def tearDown(self) -> None:
        pass

    def test_create_digit_token(self) -> None:
        """Test case for create_digit_token

        Generate a digit token
        """
        pass

    def test_get_identity_password_change_status(self) -> None:
        """Test case for get_identity_password_change_status

        Get password change request status
        """
        pass

    def test_query_password_info(self) -> None:
        """Test case for query_password_info

        Query password info
        """
        pass

    def test_set_identity_password(self) -> None:
        """Test case for set_identity_password

        Set identity's password
        """
        pass


if __name__ == '__main__':
    unittest.main()
