# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.mfa_configuration_api import MFAConfigurationApi


class TestMFAConfigurationApi(unittest.TestCase):
    """MFAConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MFAConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_delete_mfa_config(self) -> None:
        """Test case for delete_mfa_config

        Delete mfa method configuration
        """
        pass

    def test_get_mfa_duo_config(self) -> None:
        """Test case for get_mfa_duo_config

        Configuration of duo mfa method
        """
        pass

    def test_get_mfa_kba_config(self) -> None:
        """Test case for get_mfa_kba_config

        Configuration of kba mfa method
        """
        pass

    def test_get_mfa_okta_config(self) -> None:
        """Test case for get_mfa_okta_config

        Configuration of okta mfa method
        """
        pass

    def test_set_mfa_duo_config(self) -> None:
        """Test case for set_mfa_duo_config

        Set duo mfa configuration
        """
        pass

    def test_set_mfa_okta_config(self) -> None:
        """Test case for set_mfa_okta_config

        Set okta mfa configuration
        """
        pass

    def test_set_mfakba_config(self) -> None:
        """Test case for set_mfakba_config

        Set mfa kba configuration
        """
        pass

    def test_test_mfa_config(self) -> None:
        """Test case for test_mfa_config

        Mfa method's test configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
