# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.machine_identities_api import MachineIdentitiesApi


class TestMachineIdentitiesApi(unittest.TestCase):
    """MachineIdentitiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MachineIdentitiesApi()

    def tearDown(self) -> None:
        pass

    def test_create_machine_identity(self) -> None:
        """Test case for create_machine_identity

        Create machine identities
        """
        pass

    def test_delete_machine_identity(self) -> None:
        """Test case for delete_machine_identity

        Delete machine identity
        """
        pass

    def test_get_machine_identity(self) -> None:
        """Test case for get_machine_identity

        Machine identity details
        """
        pass

    def test_list_machine_identities(self) -> None:
        """Test case for list_machine_identities

        List machine identities
        """
        pass

    def test_update_machine_identity(self) -> None:
        """Test case for update_machine_identity

        Update a machine identity
        """
        pass


if __name__ == '__main__':
    unittest.main()
