# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.icons_api import IconsApi


class TestIconsApi(unittest.TestCase):
    """IconsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IconsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_icon(self) -> None:
        """Test case for delete_icon

        Delete an icon
        """
        pass

    def test_set_icon(self) -> None:
        """Test case for set_icon

        Update an icon
        """
        pass


if __name__ == '__main__':
    unittest.main()
