# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.workflows_api import WorkflowsApi


class TestWorkflowsApi(unittest.TestCase):
    """WorkflowsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkflowsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_workflow_execution(self) -> None:
        """Test case for cancel_workflow_execution

        Cancel workflow execution by id
        """
        pass

    def test_create_external_execute_workflow(self) -> None:
        """Test case for create_external_execute_workflow

        Execute workflow via external trigger
        """
        pass

    def test_create_workflow(self) -> None:
        """Test case for create_workflow

        Create workflow
        """
        pass

    def test_create_workflow_external_trigger(self) -> None:
        """Test case for create_workflow_external_trigger

        Generate external trigger oauth client
        """
        pass

    def test_delete_workflow(self) -> None:
        """Test case for delete_workflow

        Delete workflow by id
        """
        pass

    def test_get_workflow(self) -> None:
        """Test case for get_workflow

        Get workflow by id
        """
        pass

    def test_get_workflow_execution(self) -> None:
        """Test case for get_workflow_execution

        Get workflow execution
        """
        pass

    def test_get_workflow_execution_history(self) -> None:
        """Test case for get_workflow_execution_history

        Get workflow execution history
        """
        pass

    def test_get_workflow_executions(self) -> None:
        """Test case for get_workflow_executions

        List workflow executions
        """
        pass

    def test_list_complete_workflow_library(self) -> None:
        """Test case for list_complete_workflow_library

        List complete workflow library
        """
        pass

    def test_list_workflow_library_actions(self) -> None:
        """Test case for list_workflow_library_actions

        List workflow library actions
        """
        pass

    def test_list_workflow_library_operators(self) -> None:
        """Test case for list_workflow_library_operators

        List workflow library operators
        """
        pass

    def test_list_workflow_library_triggers(self) -> None:
        """Test case for list_workflow_library_triggers

        List workflow library triggers
        """
        pass

    def test_list_workflows(self) -> None:
        """Test case for list_workflows

        List workflows
        """
        pass

    def test_patch_workflow(self) -> None:
        """Test case for patch_workflow

        Patch workflow
        """
        pass

    def test_put_workflow(self) -> None:
        """Test case for put_workflow

        Update workflow
        """
        pass

    def test_test_external_execute_workflow(self) -> None:
        """Test case for test_external_execute_workflow

        Test workflow via external trigger
        """
        pass

    def test_test_workflow(self) -> None:
        """Test case for test_workflow

        Test workflow by id
        """
        pass


if __name__ == '__main__':
    unittest.main()
