# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json
import warnings

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SedBatchRecord(BaseModel):
    """
    Sed Batch Record
    """ # noqa: E501
    tenant_id: Optional[StrictStr] = Field(default=None, description="The tenant ID associated with the batch.", alias="tenantId")
    batch_id: Optional[StrictStr] = Field(default=None, description="The unique ID of the batch.", alias="batchId")
    name: Optional[StrictStr] = Field(default=None, description="The name of the batch.")
    processed_state: Optional[StrictStr] = Field(default=None, description="The current state of the batch (e.g., submitted, materialized, completed).", alias="processedState")
    requested_by: Optional[StrictStr] = Field(default=None, description="The ID of the user who requested the batch.", alias="requestedBy")
    materialized_count: Optional[StrictInt] = Field(default=None, description="The number of items materialized in the batch.", alias="materializedCount")
    processed_count: Optional[StrictInt] = Field(default=None, description="The number of items processed in the batch.", alias="processedCount")
    created_at: Optional[datetime] = Field(default=None, description="The timestamp when the batch was created.", alias="createdAt")
    updated_at: Optional[datetime] = Field(default=None, description="The timestamp when the batch was last updated.", alias="updatedAt")
    __properties: ClassVar[List[str]] = ["tenantId", "batchId", "name", "processedState", "requestedBy", "materializedCount", "processedCount", "createdAt", "updatedAt"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SedBatchRecord from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if processed_state (nullable) is None
        # and model_fields_set contains the field
        if self.processed_state is None and "processed_state" in self.model_fields_set:
            _dict['processedState'] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict['updatedAt'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SedBatchRecord from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "tenantId": obj.get("tenantId"),
            "batchId": obj.get("batchId"),
            "name": obj.get("name"),
            "processedState": obj.get("processedState"),
            "requestedBy": obj.get("requestedBy"),
            "materializedCount": obj.get("materializedCount"),
            "processedCount": obj.get("processedCount"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt")
        })
        return _obj


