# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.connector_customizers_api import ConnectorCustomizersApi


class TestConnectorCustomizersApi(unittest.TestCase):
    """ConnectorCustomizersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConnectorCustomizersApi()

    def tearDown(self) -> None:
        pass

    def test_create_connector_customizer(self) -> None:
        """Test case for create_connector_customizer

        Create connector customizer
        """
        pass

    def test_create_connector_customizer_version(self) -> None:
        """Test case for create_connector_customizer_version

        Creates a connector customizer version
        """
        pass

    def test_delete_connector_customizer(self) -> None:
        """Test case for delete_connector_customizer

        Delete connector customizer
        """
        pass

    def test_get_connector_customizer(self) -> None:
        """Test case for get_connector_customizer

        Get connector customizer
        """
        pass

    def test_list_connector_customizers(self) -> None:
        """Test case for list_connector_customizers

        List all connector customizers
        """
        pass

    def test_put_connector_customizer(self) -> None:
        """Test case for put_connector_customizer

        Update connector customizer
        """
        pass


if __name__ == '__main__':
    unittest.main()
