# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.access_requests_api import AccessRequestsApi


class TestAccessRequestsApi(unittest.TestCase):
    """AccessRequestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccessRequestsApi()

    def tearDown(self) -> None:
        pass

    def test_approve_bulk_access_request(self) -> None:
        """Test case for approve_bulk_access_request

        Bulk approve access request
        """
        pass

    def test_cancel_access_request(self) -> None:
        """Test case for cancel_access_request

        Cancel access request
        """
        pass

    def test_cancel_access_request_in_bulk(self) -> None:
        """Test case for cancel_access_request_in_bulk

        Bulk cancel access request
        """
        pass

    def test_close_access_request(self) -> None:
        """Test case for close_access_request

        Close access request
        """
        pass

    def test_create_access_request(self) -> None:
        """Test case for create_access_request

        Submit access request
        """
        pass

    def test_get_access_request_config(self) -> None:
        """Test case for get_access_request_config

        Get access request configuration
        """
        pass

    def test_list_access_request_status(self) -> None:
        """Test case for list_access_request_status

        Access request status
        """
        pass

    def test_list_administrators_access_request_status(self) -> None:
        """Test case for list_administrators_access_request_status

        Access request status for administrators
        """
        pass

    def test_load_account_selections(self) -> None:
        """Test case for load_account_selections

        Get accounts selections for identity
        """
        pass

    def test_set_access_request_config(self) -> None:
        """Test case for set_access_request_config

        Update access request configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
