# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.password_sync_groups_api import PasswordSyncGroupsApi


class TestPasswordSyncGroupsApi(unittest.TestCase):
    """PasswordSyncGroupsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PasswordSyncGroupsApi()

    def tearDown(self) -> None:
        pass

    def test_create_password_sync_group(self) -> None:
        """Test case for create_password_sync_group

        Create password sync group
        """
        pass

    def test_delete_password_sync_group(self) -> None:
        """Test case for delete_password_sync_group

        Delete password sync group by id
        """
        pass

    def test_get_password_sync_group(self) -> None:
        """Test case for get_password_sync_group

        Get password sync group by id
        """
        pass

    def test_get_password_sync_groups(self) -> None:
        """Test case for get_password_sync_groups

        Get password sync group list
        """
        pass

    def test_update_password_sync_group(self) -> None:
        """Test case for update_password_sync_group

        Update password sync group by id
        """
        pass


if __name__ == '__main__':
    unittest.main()
