# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.access_model_metadata_api import AccessModelMetadataApi


class TestAccessModelMetadataApi(unittest.TestCase):
    """AccessModelMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccessModelMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_get_access_model_metadata_attribute(self) -> None:
        """Test case for get_access_model_metadata_attribute

        Get access model metadata attribute
        """
        pass

    def test_get_access_model_metadata_attribute_value(self) -> None:
        """Test case for get_access_model_metadata_attribute_value

        Get access model metadata value
        """
        pass

    def test_list_access_model_metadata_attribute(self) -> None:
        """Test case for list_access_model_metadata_attribute

        List access model metadata attributes
        """
        pass

    def test_list_access_model_metadata_attribute_value(self) -> None:
        """Test case for list_access_model_metadata_attribute_value

        List access model metadata values
        """
        pass


if __name__ == '__main__':
    unittest.main()
