# coding: utf-8

"""
    Identity Security Cloud Beta API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.tags_api import TagsApi


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TagsApi()

    def tearDown(self) -> None:
        pass

    def test_create_tag(self) -> None:
        """Test case for create_tag

        Create tag
        """
        pass

    def test_delete_tag_by_id(self) -> None:
        """Test case for delete_tag_by_id

        Delete tag
        """
        pass

    def test_get_tag_by_id(self) -> None:
        """Test case for get_tag_by_id

        Get tag by id
        """
        pass

    def test_list_tags(self) -> None:
        """Test case for list_tags

        List tags
        """
        pass


if __name__ == '__main__':
    unittest.main()
