# coding: utf-8

"""
    Identity Security Cloud V2024 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2024
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2024.api.managed_clients_api import ManagedClientsApi


class TestManagedClientsApi(unittest.TestCase):
    """ManagedClientsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManagedClientsApi()

    def tearDown(self) -> None:
        pass

    def test_create_managed_client(self) -> None:
        """Test case for create_managed_client

        Create managed client
        """
        pass

    def test_delete_managed_client(self) -> None:
        """Test case for delete_managed_client

        Delete managed client
        """
        pass

    def test_get_managed_client(self) -> None:
        """Test case for get_managed_client

        Get managed client
        """
        pass

    def test_get_managed_client_status(self) -> None:
        """Test case for get_managed_client_status

        Get managed client status
        """
        pass

    def test_get_managed_clients(self) -> None:
        """Test case for get_managed_clients

        Get managed clients
        """
        pass

    def test_update_managed_client(self) -> None:
        """Test case for update_managed_client

        Update managed client
        """
        pass


if __name__ == '__main__':
    unittest.main()
