# coding: utf-8

"""
    Identity Security Cloud V2025 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: v2025
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v2025.api.ui_metadata_api import UIMetadataApi


class TestUIMetadataApi(unittest.TestCase):
    """UIMetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UIMetadataApi()

    def tearDown(self) -> None:
        pass

    def test_get_tenant_ui_metadata(self) -> None:
        """Test case for get_tenant_ui_metadata

        Get a tenant ui metadata
        """
        pass

    def test_set_tenant_ui_metadata(self) -> None:
        """Test case for set_tenant_ui_metadata

        Update tenant ui metadata
        """
        pass


if __name__ == '__main__':
    unittest.main()
