# coding: utf-8

"""
    Identity Security Cloud V3 API

    Use these APIs to interact with the Identity Security Cloud platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.search_attribute_configuration_api import SearchAttributeConfigurationApi


class TestSearchAttributeConfigurationApi(unittest.TestCase):
    """SearchAttributeConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SearchAttributeConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_search_attribute_config(self) -> None:
        """Test case for create_search_attribute_config

        Create extended search attributes
        """
        pass

    def test_delete_search_attribute_config(self) -> None:
        """Test case for delete_search_attribute_config

        Delete extended search attribute
        """
        pass

    def test_get_search_attribute_config(self) -> None:
        """Test case for get_search_attribute_config

        List extended search attributes
        """
        pass

    def test_get_single_search_attribute_config(self) -> None:
        """Test case for get_single_search_attribute_config

        Get extended search attribute
        """
        pass

    def test_patch_search_attribute_config(self) -> None:
        """Test case for patch_search_attribute_config

        Update extended search attribute
        """
        pass


if __name__ == '__main__':
    unittest.main()
